s3user

package
v0.0.12 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 20, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the s3user type in the database.
	Label = "s3user"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldFkUserID holds the string denoting the fk_user_id field in the database.
	FieldFkUserID = "fk_user_id"
	// FieldType holds the string denoting the type field in the database.
	FieldType = "type"
	// FieldAccessKey holds the string denoting the access_key field in the database.
	FieldAccessKey = "access_key"
	// FieldSecretKey holds the string denoting the secret_key field in the database.
	FieldSecretKey = "secret_key"
	// FieldCreateTime holds the string denoting the create_time field in the database.
	FieldCreateTime = "create_time"
	// FieldUpdateTime holds the string denoting the update_time field in the database.
	FieldUpdateTime = "update_time"
	// Table holds the table name of the s3user in the database.
	Table = "s3users"
)

Variables

var (
	// AccessKeyValidator is a validator for the "access_key" field. It is called by the builders before save.
	AccessKeyValidator func(string) error
	// SecretKeyValidator is a validator for the "secret_key" field. It is called by the builders before save.
	SecretKeyValidator func(string) error
	// DefaultCreateTime holds the default value on creation for the "create_time" field.
	DefaultCreateTime func() time.Time
	// DefaultUpdateTime holds the default value on creation for the "update_time" field.
	DefaultUpdateTime func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for s3user fields.

Functions

func AccessKey

func AccessKey(v string) predicate.S3User

AccessKey applies equality check predicate on the "access_key" field. It's identical to AccessKeyEQ.

func AccessKeyContains

func AccessKeyContains(v string) predicate.S3User

AccessKeyContains applies the Contains predicate on the "access_key" field.

func AccessKeyContainsFold

func AccessKeyContainsFold(v string) predicate.S3User

AccessKeyContainsFold applies the ContainsFold predicate on the "access_key" field.

func AccessKeyEQ

func AccessKeyEQ(v string) predicate.S3User

AccessKeyEQ applies the EQ predicate on the "access_key" field.

func AccessKeyEqualFold

func AccessKeyEqualFold(v string) predicate.S3User

AccessKeyEqualFold applies the EqualFold predicate on the "access_key" field.

func AccessKeyGT

func AccessKeyGT(v string) predicate.S3User

AccessKeyGT applies the GT predicate on the "access_key" field.

func AccessKeyGTE

func AccessKeyGTE(v string) predicate.S3User

AccessKeyGTE applies the GTE predicate on the "access_key" field.

func AccessKeyHasPrefix

func AccessKeyHasPrefix(v string) predicate.S3User

AccessKeyHasPrefix applies the HasPrefix predicate on the "access_key" field.

func AccessKeyHasSuffix

func AccessKeyHasSuffix(v string) predicate.S3User

AccessKeyHasSuffix applies the HasSuffix predicate on the "access_key" field.

func AccessKeyIn

func AccessKeyIn(vs ...string) predicate.S3User

AccessKeyIn applies the In predicate on the "access_key" field.

func AccessKeyLT

func AccessKeyLT(v string) predicate.S3User

AccessKeyLT applies the LT predicate on the "access_key" field.

func AccessKeyLTE

func AccessKeyLTE(v string) predicate.S3User

AccessKeyLTE applies the LTE predicate on the "access_key" field.

func AccessKeyNEQ

func AccessKeyNEQ(v string) predicate.S3User

AccessKeyNEQ applies the NEQ predicate on the "access_key" field.

func AccessKeyNotIn

func AccessKeyNotIn(vs ...string) predicate.S3User

AccessKeyNotIn applies the NotIn predicate on the "access_key" field.

func And

func And(predicates ...predicate.S3User) predicate.S3User

And groups predicates with the AND operator between them.

func CreateTime

func CreateTime(v time.Time) predicate.S3User

CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.

func CreateTimeEQ

func CreateTimeEQ(v time.Time) predicate.S3User

CreateTimeEQ applies the EQ predicate on the "create_time" field.

func CreateTimeGT

func CreateTimeGT(v time.Time) predicate.S3User

CreateTimeGT applies the GT predicate on the "create_time" field.

func CreateTimeGTE

func CreateTimeGTE(v time.Time) predicate.S3User

CreateTimeGTE applies the GTE predicate on the "create_time" field.

func CreateTimeIn

func CreateTimeIn(vs ...time.Time) predicate.S3User

CreateTimeIn applies the In predicate on the "create_time" field.

func CreateTimeLT

func CreateTimeLT(v time.Time) predicate.S3User

CreateTimeLT applies the LT predicate on the "create_time" field.

func CreateTimeLTE

func CreateTimeLTE(v time.Time) predicate.S3User

CreateTimeLTE applies the LTE predicate on the "create_time" field.

func CreateTimeNEQ

func CreateTimeNEQ(v time.Time) predicate.S3User

CreateTimeNEQ applies the NEQ predicate on the "create_time" field.

func CreateTimeNotIn

func CreateTimeNotIn(vs ...time.Time) predicate.S3User

CreateTimeNotIn applies the NotIn predicate on the "create_time" field.

func FkUserID

func FkUserID(v uuid.UUID) predicate.S3User

FkUserID applies equality check predicate on the "fk_user_id" field. It's identical to FkUserIDEQ.

func FkUserIDEQ

func FkUserIDEQ(v uuid.UUID) predicate.S3User

FkUserIDEQ applies the EQ predicate on the "fk_user_id" field.

func FkUserIDGT

func FkUserIDGT(v uuid.UUID) predicate.S3User

FkUserIDGT applies the GT predicate on the "fk_user_id" field.

func FkUserIDGTE

func FkUserIDGTE(v uuid.UUID) predicate.S3User

FkUserIDGTE applies the GTE predicate on the "fk_user_id" field.

func FkUserIDIn

func FkUserIDIn(vs ...uuid.UUID) predicate.S3User

FkUserIDIn applies the In predicate on the "fk_user_id" field.

func FkUserIDLT

func FkUserIDLT(v uuid.UUID) predicate.S3User

FkUserIDLT applies the LT predicate on the "fk_user_id" field.

func FkUserIDLTE

func FkUserIDLTE(v uuid.UUID) predicate.S3User

FkUserIDLTE applies the LTE predicate on the "fk_user_id" field.

func FkUserIDNEQ

func FkUserIDNEQ(v uuid.UUID) predicate.S3User

FkUserIDNEQ applies the NEQ predicate on the "fk_user_id" field.

func FkUserIDNotIn

func FkUserIDNotIn(vs ...uuid.UUID) predicate.S3User

FkUserIDNotIn applies the NotIn predicate on the "fk_user_id" field.

func ID

func ID(id uuid.UUID) predicate.S3User

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.S3User

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.S3User

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.S3User

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.S3User

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.S3User

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.S3User

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.S3User

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.S3User

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.S3User) predicate.S3User

Or groups predicates with the OR operator between them.

func SecretKey

func SecretKey(v string) predicate.S3User

SecretKey applies equality check predicate on the "secret_key" field. It's identical to SecretKeyEQ.

func SecretKeyContains

func SecretKeyContains(v string) predicate.S3User

SecretKeyContains applies the Contains predicate on the "secret_key" field.

func SecretKeyContainsFold

func SecretKeyContainsFold(v string) predicate.S3User

SecretKeyContainsFold applies the ContainsFold predicate on the "secret_key" field.

func SecretKeyEQ

func SecretKeyEQ(v string) predicate.S3User

SecretKeyEQ applies the EQ predicate on the "secret_key" field.

func SecretKeyEqualFold

func SecretKeyEqualFold(v string) predicate.S3User

SecretKeyEqualFold applies the EqualFold predicate on the "secret_key" field.

func SecretKeyGT

func SecretKeyGT(v string) predicate.S3User

SecretKeyGT applies the GT predicate on the "secret_key" field.

func SecretKeyGTE

func SecretKeyGTE(v string) predicate.S3User

SecretKeyGTE applies the GTE predicate on the "secret_key" field.

func SecretKeyHasPrefix

func SecretKeyHasPrefix(v string) predicate.S3User

SecretKeyHasPrefix applies the HasPrefix predicate on the "secret_key" field.

func SecretKeyHasSuffix

func SecretKeyHasSuffix(v string) predicate.S3User

SecretKeyHasSuffix applies the HasSuffix predicate on the "secret_key" field.

func SecretKeyIn

func SecretKeyIn(vs ...string) predicate.S3User

SecretKeyIn applies the In predicate on the "secret_key" field.

func SecretKeyLT

func SecretKeyLT(v string) predicate.S3User

SecretKeyLT applies the LT predicate on the "secret_key" field.

func SecretKeyLTE

func SecretKeyLTE(v string) predicate.S3User

SecretKeyLTE applies the LTE predicate on the "secret_key" field.

func SecretKeyNEQ

func SecretKeyNEQ(v string) predicate.S3User

SecretKeyNEQ applies the NEQ predicate on the "secret_key" field.

func SecretKeyNotIn

func SecretKeyNotIn(vs ...string) predicate.S3User

SecretKeyNotIn applies the NotIn predicate on the "secret_key" field.

func Type

func Type(v int8) predicate.S3User

Type applies equality check predicate on the "type" field. It's identical to TypeEQ.

func TypeEQ

func TypeEQ(v int8) predicate.S3User

TypeEQ applies the EQ predicate on the "type" field.

func TypeGT

func TypeGT(v int8) predicate.S3User

TypeGT applies the GT predicate on the "type" field.

func TypeGTE

func TypeGTE(v int8) predicate.S3User

TypeGTE applies the GTE predicate on the "type" field.

func TypeIn

func TypeIn(vs ...int8) predicate.S3User

TypeIn applies the In predicate on the "type" field.

func TypeLT

func TypeLT(v int8) predicate.S3User

TypeLT applies the LT predicate on the "type" field.

func TypeLTE

func TypeLTE(v int8) predicate.S3User

TypeLTE applies the LTE predicate on the "type" field.

func TypeNEQ

func TypeNEQ(v int8) predicate.S3User

TypeNEQ applies the NEQ predicate on the "type" field.

func TypeNotIn

func TypeNotIn(vs ...int8) predicate.S3User

TypeNotIn applies the NotIn predicate on the "type" field.

func UpdateTime

func UpdateTime(v time.Time) predicate.S3User

UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.

func UpdateTimeEQ

func UpdateTimeEQ(v time.Time) predicate.S3User

UpdateTimeEQ applies the EQ predicate on the "update_time" field.

func UpdateTimeGT

func UpdateTimeGT(v time.Time) predicate.S3User

UpdateTimeGT applies the GT predicate on the "update_time" field.

func UpdateTimeGTE

func UpdateTimeGTE(v time.Time) predicate.S3User

UpdateTimeGTE applies the GTE predicate on the "update_time" field.

func UpdateTimeIn

func UpdateTimeIn(vs ...time.Time) predicate.S3User

UpdateTimeIn applies the In predicate on the "update_time" field.

func UpdateTimeLT

func UpdateTimeLT(v time.Time) predicate.S3User

UpdateTimeLT applies the LT predicate on the "update_time" field.

func UpdateTimeLTE

func UpdateTimeLTE(v time.Time) predicate.S3User

UpdateTimeLTE applies the LTE predicate on the "update_time" field.

func UpdateTimeNEQ

func UpdateTimeNEQ(v time.Time) predicate.S3User

UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.

func UpdateTimeNotIn

func UpdateTimeNotIn(vs ...time.Time) predicate.S3User

UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the S3User queries.

func ByAccessKey

func ByAccessKey(opts ...sql.OrderTermOption) OrderOption

ByAccessKey orders the results by the access_key field.

func ByCreateTime

func ByCreateTime(opts ...sql.OrderTermOption) OrderOption

ByCreateTime orders the results by the create_time field.

func ByFkUserID

func ByFkUserID(opts ...sql.OrderTermOption) OrderOption

ByFkUserID orders the results by the fk_user_id field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func BySecretKey

func BySecretKey(opts ...sql.OrderTermOption) OrderOption

BySecretKey orders the results by the secret_key field.

func ByType

func ByType(opts ...sql.OrderTermOption) OrderOption

ByType orders the results by the type field.

func ByUpdateTime

func ByUpdateTime(opts ...sql.OrderTermOption) OrderOption

ByUpdateTime orders the results by the update_time field.

Jump to