Documentation
¶
Index ¶
- Constants
- Variables
- func AccessKey(v string) predicate.S3User
- func AccessKeyContains(v string) predicate.S3User
- func AccessKeyContainsFold(v string) predicate.S3User
- func AccessKeyEQ(v string) predicate.S3User
- func AccessKeyEqualFold(v string) predicate.S3User
- func AccessKeyGT(v string) predicate.S3User
- func AccessKeyGTE(v string) predicate.S3User
- func AccessKeyHasPrefix(v string) predicate.S3User
- func AccessKeyHasSuffix(v string) predicate.S3User
- func AccessKeyIn(vs ...string) predicate.S3User
- func AccessKeyLT(v string) predicate.S3User
- func AccessKeyLTE(v string) predicate.S3User
- func AccessKeyNEQ(v string) predicate.S3User
- func AccessKeyNotIn(vs ...string) predicate.S3User
- func And(predicates ...predicate.S3User) predicate.S3User
- func CreateTime(v time.Time) predicate.S3User
- func CreateTimeEQ(v time.Time) predicate.S3User
- func CreateTimeGT(v time.Time) predicate.S3User
- func CreateTimeGTE(v time.Time) predicate.S3User
- func CreateTimeIn(vs ...time.Time) predicate.S3User
- func CreateTimeLT(v time.Time) predicate.S3User
- func CreateTimeLTE(v time.Time) predicate.S3User
- func CreateTimeNEQ(v time.Time) predicate.S3User
- func CreateTimeNotIn(vs ...time.Time) predicate.S3User
- func FkUserID(v uuid.UUID) predicate.S3User
- func FkUserIDEQ(v uuid.UUID) predicate.S3User
- func FkUserIDGT(v uuid.UUID) predicate.S3User
- func FkUserIDGTE(v uuid.UUID) predicate.S3User
- func FkUserIDIn(vs ...uuid.UUID) predicate.S3User
- func FkUserIDLT(v uuid.UUID) predicate.S3User
- func FkUserIDLTE(v uuid.UUID) predicate.S3User
- func FkUserIDNEQ(v uuid.UUID) predicate.S3User
- func FkUserIDNotIn(vs ...uuid.UUID) predicate.S3User
- func ID(id uuid.UUID) predicate.S3User
- func IDEQ(id uuid.UUID) predicate.S3User
- func IDGT(id uuid.UUID) predicate.S3User
- func IDGTE(id uuid.UUID) predicate.S3User
- func IDIn(ids ...uuid.UUID) predicate.S3User
- func IDLT(id uuid.UUID) predicate.S3User
- func IDLTE(id uuid.UUID) predicate.S3User
- func IDNEQ(id uuid.UUID) predicate.S3User
- func IDNotIn(ids ...uuid.UUID) predicate.S3User
- func Not(p predicate.S3User) predicate.S3User
- func Or(predicates ...predicate.S3User) predicate.S3User
- func SecretKey(v string) predicate.S3User
- func SecretKeyContains(v string) predicate.S3User
- func SecretKeyContainsFold(v string) predicate.S3User
- func SecretKeyEQ(v string) predicate.S3User
- func SecretKeyEqualFold(v string) predicate.S3User
- func SecretKeyGT(v string) predicate.S3User
- func SecretKeyGTE(v string) predicate.S3User
- func SecretKeyHasPrefix(v string) predicate.S3User
- func SecretKeyHasSuffix(v string) predicate.S3User
- func SecretKeyIn(vs ...string) predicate.S3User
- func SecretKeyLT(v string) predicate.S3User
- func SecretKeyLTE(v string) predicate.S3User
- func SecretKeyNEQ(v string) predicate.S3User
- func SecretKeyNotIn(vs ...string) predicate.S3User
- func Type(v int8) predicate.S3User
- func TypeEQ(v int8) predicate.S3User
- func TypeGT(v int8) predicate.S3User
- func TypeGTE(v int8) predicate.S3User
- func TypeIn(vs ...int8) predicate.S3User
- func TypeLT(v int8) predicate.S3User
- func TypeLTE(v int8) predicate.S3User
- func TypeNEQ(v int8) predicate.S3User
- func TypeNotIn(vs ...int8) predicate.S3User
- func UpdateTime(v time.Time) predicate.S3User
- func UpdateTimeEQ(v time.Time) predicate.S3User
- func UpdateTimeGT(v time.Time) predicate.S3User
- func UpdateTimeGTE(v time.Time) predicate.S3User
- func UpdateTimeIn(vs ...time.Time) predicate.S3User
- func UpdateTimeLT(v time.Time) predicate.S3User
- func UpdateTimeLTE(v time.Time) predicate.S3User
- func UpdateTimeNEQ(v time.Time) predicate.S3User
- func UpdateTimeNotIn(vs ...time.Time) predicate.S3User
- func ValidColumn(column string) bool
- type OrderOption
- func ByAccessKey(opts ...sql.OrderTermOption) OrderOption
- func ByCreateTime(opts ...sql.OrderTermOption) OrderOption
- func ByFkUserID(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func BySecretKey(opts ...sql.OrderTermOption) OrderOption
- func ByType(opts ...sql.OrderTermOption) OrderOption
- func ByUpdateTime(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the s3user type in the database. Label = "s3user" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldFkUserID holds the string denoting the fk_user_id field in the database. FieldFkUserID = "fk_user_id" // FieldType holds the string denoting the type field in the database. FieldType = "type" // FieldAccessKey holds the string denoting the access_key field in the database. FieldAccessKey = "access_key" // FieldSecretKey holds the string denoting the secret_key field in the database. FieldSecretKey = "secret_key" // FieldCreateTime holds the string denoting the create_time field in the database. FieldCreateTime = "create_time" // FieldUpdateTime holds the string denoting the update_time field in the database. FieldUpdateTime = "update_time" // Table holds the table name of the s3user in the database. Table = "s3users" )
Variables ¶
var ( // AccessKeyValidator is a validator for the "access_key" field. It is called by the builders before save. AccessKeyValidator func(string) error // SecretKeyValidator is a validator for the "secret_key" field. It is called by the builders before save. SecretKeyValidator func(string) error // DefaultCreateTime holds the default value on creation for the "create_time" field. DefaultCreateTime func() time.Time // DefaultUpdateTime holds the default value on creation for the "update_time" field. DefaultUpdateTime func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldFkUserID, FieldType, FieldAccessKey, FieldSecretKey, FieldCreateTime, FieldUpdateTime, }
Columns holds all SQL columns for s3user fields.
Functions ¶
func AccessKey ¶
AccessKey applies equality check predicate on the "access_key" field. It's identical to AccessKeyEQ.
func AccessKeyContains ¶
AccessKeyContains applies the Contains predicate on the "access_key" field.
func AccessKeyContainsFold ¶
AccessKeyContainsFold applies the ContainsFold predicate on the "access_key" field.
func AccessKeyEQ ¶
AccessKeyEQ applies the EQ predicate on the "access_key" field.
func AccessKeyEqualFold ¶
AccessKeyEqualFold applies the EqualFold predicate on the "access_key" field.
func AccessKeyGT ¶
AccessKeyGT applies the GT predicate on the "access_key" field.
func AccessKeyGTE ¶
AccessKeyGTE applies the GTE predicate on the "access_key" field.
func AccessKeyHasPrefix ¶
AccessKeyHasPrefix applies the HasPrefix predicate on the "access_key" field.
func AccessKeyHasSuffix ¶
AccessKeyHasSuffix applies the HasSuffix predicate on the "access_key" field.
func AccessKeyIn ¶
AccessKeyIn applies the In predicate on the "access_key" field.
func AccessKeyLT ¶
AccessKeyLT applies the LT predicate on the "access_key" field.
func AccessKeyLTE ¶
AccessKeyLTE applies the LTE predicate on the "access_key" field.
func AccessKeyNEQ ¶
AccessKeyNEQ applies the NEQ predicate on the "access_key" field.
func AccessKeyNotIn ¶
AccessKeyNotIn applies the NotIn predicate on the "access_key" field.
func CreateTime ¶
CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.
func CreateTimeEQ ¶
CreateTimeEQ applies the EQ predicate on the "create_time" field.
func CreateTimeGT ¶
CreateTimeGT applies the GT predicate on the "create_time" field.
func CreateTimeGTE ¶
CreateTimeGTE applies the GTE predicate on the "create_time" field.
func CreateTimeIn ¶
CreateTimeIn applies the In predicate on the "create_time" field.
func CreateTimeLT ¶
CreateTimeLT applies the LT predicate on the "create_time" field.
func CreateTimeLTE ¶
CreateTimeLTE applies the LTE predicate on the "create_time" field.
func CreateTimeNEQ ¶
CreateTimeNEQ applies the NEQ predicate on the "create_time" field.
func CreateTimeNotIn ¶
CreateTimeNotIn applies the NotIn predicate on the "create_time" field.
func FkUserID ¶
FkUserID applies equality check predicate on the "fk_user_id" field. It's identical to FkUserIDEQ.
func FkUserIDEQ ¶
FkUserIDEQ applies the EQ predicate on the "fk_user_id" field.
func FkUserIDGT ¶
FkUserIDGT applies the GT predicate on the "fk_user_id" field.
func FkUserIDGTE ¶
FkUserIDGTE applies the GTE predicate on the "fk_user_id" field.
func FkUserIDIn ¶
FkUserIDIn applies the In predicate on the "fk_user_id" field.
func FkUserIDLT ¶
FkUserIDLT applies the LT predicate on the "fk_user_id" field.
func FkUserIDLTE ¶
FkUserIDLTE applies the LTE predicate on the "fk_user_id" field.
func FkUserIDNEQ ¶
FkUserIDNEQ applies the NEQ predicate on the "fk_user_id" field.
func FkUserIDNotIn ¶
FkUserIDNotIn applies the NotIn predicate on the "fk_user_id" field.
func SecretKey ¶
SecretKey applies equality check predicate on the "secret_key" field. It's identical to SecretKeyEQ.
func SecretKeyContains ¶
SecretKeyContains applies the Contains predicate on the "secret_key" field.
func SecretKeyContainsFold ¶
SecretKeyContainsFold applies the ContainsFold predicate on the "secret_key" field.
func SecretKeyEQ ¶
SecretKeyEQ applies the EQ predicate on the "secret_key" field.
func SecretKeyEqualFold ¶
SecretKeyEqualFold applies the EqualFold predicate on the "secret_key" field.
func SecretKeyGT ¶
SecretKeyGT applies the GT predicate on the "secret_key" field.
func SecretKeyGTE ¶
SecretKeyGTE applies the GTE predicate on the "secret_key" field.
func SecretKeyHasPrefix ¶
SecretKeyHasPrefix applies the HasPrefix predicate on the "secret_key" field.
func SecretKeyHasSuffix ¶
SecretKeyHasSuffix applies the HasSuffix predicate on the "secret_key" field.
func SecretKeyIn ¶
SecretKeyIn applies the In predicate on the "secret_key" field.
func SecretKeyLT ¶
SecretKeyLT applies the LT predicate on the "secret_key" field.
func SecretKeyLTE ¶
SecretKeyLTE applies the LTE predicate on the "secret_key" field.
func SecretKeyNEQ ¶
SecretKeyNEQ applies the NEQ predicate on the "secret_key" field.
func SecretKeyNotIn ¶
SecretKeyNotIn applies the NotIn predicate on the "secret_key" field.
func UpdateTime ¶
UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.
func UpdateTimeEQ ¶
UpdateTimeEQ applies the EQ predicate on the "update_time" field.
func UpdateTimeGT ¶
UpdateTimeGT applies the GT predicate on the "update_time" field.
func UpdateTimeGTE ¶
UpdateTimeGTE applies the GTE predicate on the "update_time" field.
func UpdateTimeIn ¶
UpdateTimeIn applies the In predicate on the "update_time" field.
func UpdateTimeLT ¶
UpdateTimeLT applies the LT predicate on the "update_time" field.
func UpdateTimeLTE ¶
UpdateTimeLTE applies the LTE predicate on the "update_time" field.
func UpdateTimeNEQ ¶
UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.
func UpdateTimeNotIn ¶
UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the S3User queries.
func ByAccessKey ¶
func ByAccessKey(opts ...sql.OrderTermOption) OrderOption
ByAccessKey orders the results by the access_key field.
func ByCreateTime ¶
func ByCreateTime(opts ...sql.OrderTermOption) OrderOption
ByCreateTime orders the results by the create_time field.
func ByFkUserID ¶
func ByFkUserID(opts ...sql.OrderTermOption) OrderOption
ByFkUserID orders the results by the fk_user_id field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func BySecretKey ¶
func BySecretKey(opts ...sql.OrderTermOption) OrderOption
BySecretKey orders the results by the secret_key field.
func ByType ¶
func ByType(opts ...sql.OrderTermOption) OrderOption
ByType orders the results by the type field.
func ByUpdateTime ¶
func ByUpdateTime(opts ...sql.OrderTermOption) OrderOption
ByUpdateTime orders the results by the update_time field.